pub struct PackedStructDisplay<'a, P: 'a> {
pub packed_struct: &'a P,
pub header: bool,
pub raw_decimal: bool,
pub raw_hex: bool,
pub raw_binary: bool,
pub fields: bool,
}
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.