pub trait PackedStructInfo {
// Required method
fn packed_bits() -> usize;
}Expand description
Infos about a particular type that can be packaged.
Required Methods
Sourcefn packed_bits() -> usize
fn packed_bits() -> usize
Number of bits that this structure occupies when being packed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".